@@ -1,14 +1,18 @@
+import cgi
 import logging
 from gettext import gettext as _
 
 import dbus
 import gnomevfs
-import deskbar, deskbar.indexer, deskbar.locale_utils, deskbar.handler_utils
-import deskbar.handler
+import deskbar
+import deskbar.Handler
+from deskbar.BrowserMatch import BrowserMatch
 
 HANDLERS = {"DeliciousHandler" : 
             {'name' : _('del.icio.us Bookmarks'),
              'description' : _('Search your del.icio.us account'),}}
+IMAGE_FILE = '/usr/local/share/gnomolicious/gnomolicious.png'
+QUERY_DELAY = 1
 
 def init_logger():
     logger = logging.getLogger('deskbar-gnomolicious')
@@ -18,21 +22,14 @@ def init_logger():
     logger.addHandler(hdlr)
     logger.setLevel(logging.DEBUG)
 
-class DeliciousMatch(deskbar.handler.Match):
+class DeliciousMatch(BrowserMatch):
+	def __init__(self, handler, title, url, icon):
+		BrowserMatch.__init__(self, handler, title, url, icon)
 
-    def __init__(self, backend, url, description):
-        self.url = url
-        self.description = description
-        deskbar.handler.Match.__init__(self, backend, url)
+	def get_verb(self):
+		return "%(name)s"
 
-    def action(self, text=None):
-        gnomevfs.url_show(self.url)
-
-    def get_verb(self):
-        return _('Open <b>%s</b>' % self.description)
-
-
-class DeliciousHandler(deskbar.handler.AsyncHandler):
+class DeliciousHandler(deskbar.Handler.AsyncHandler):
 
     def __init__(self):
         init_logger()
@@ -40,6 +37,7 @@ class DeliciousHandler(deskbar.handler.AsyncHandler):
         self.log.info('Starting DeliciousHandler')
         super(DeliciousHandler,
               self).__init__('/usr/local/share/gnomolicious/gnomolicious.png')
+        self.server = None
 
     def initialize(self):
         self.log.info('Initializing the dbus interface')
@@ -49,12 +47,15 @@ class DeliciousHandler(deskbar.handler.AsyncHandler):
         self.dbus = dbus.Interface(proxy, 'org.gnome.GetUrlsIFace')
         self.log.debug('Initialized the dbus interface')
 
-    def query(self, qstring, qmax=5):
+    def query(self, qstring):
+        qmax = deskbar.DEFAULT_RESULTS_PER_HANDLER
+        self.check_query_changed(timeout=QUERY_DELAY)
         self.log.info('Querying dbus api for: %s' % qstring)
         urls = self.dbus.getUrls(qstring)
         self.log.info('Received: %s' % urls)
         self.check_query_changed()
         if urls:
-            return [DeliciousMatch(self, *x) for x in urls[:qmax-1]]
+            return [DeliciousMatch(self, cgi.escape(x[1]), x[0], IMAGE_FILE)
+                    for x in urls[:qmax-1]]
         else:
             return []
