@@ -18,7 +18,7 @@
 #
 #    (C) 2005-2006 Nicolas Évrard <nicoe@nutellux.be>
 
-__revision__ = "$Id: gnomolicious.py,v 1.22 2006/03/21 20:05:27 nicoe Exp $"
+__revision__ = "$Id: gnomolicious.py,v 1.24 2006/04/06 23:52:51 nicoe Exp $"
 
 import os.path
 import re
@@ -204,6 +204,7 @@ class GnomoliciousApplet(gnomeapplet.Applet):
         self.postwin.completion.set_minimum_key_length(2)
         self.postwin.completion.connect('match-selected',
                                         self.on_match_selected)
+        self.postwin.set_icon(self.logo)
 
         self.prefwin = wT.get_widget('window_pref')
         self.prefwin.entries = {'password' : wT.get_widget('entry_password'),
@@ -212,6 +213,7 @@ class GnomoliciousApplet(gnomeapplet.Applet):
                                     wT.get_widget('entry_commontagcolor'),
                                 'maxpoptag' : wT.get_widget('entry_numpoptag'),
                                 }
+        self.prefwin.set_icon(self.logo)
 
         self.update_dialog = gtk.MessageDialog(parent = None,
                                                type = gtk.MESSAGE_INFO,
@@ -304,7 +306,7 @@ class GnomoliciousApplet(gnomeapplet.Applet):
 
     def about(self, evt, data=None):
         about = gnome.ui.About("Gnomolicious",
-                               conf.version, "© 2005 Nicolas Évrard",
+                               conf.version, "© 2005-2006 Nicolas Évrard",
                                _('GNOME applet to post on del.icio.us'),
                                ['Nicolas Évrard <nicoe@nutellux.be>'], [], '', self.logo)
         about.show()
@@ -333,12 +335,13 @@ class GnomoliciousApplet(gnomeapplet.Applet):
     def on_bckg_change(self, widget, background, colour, pixmap):
         logger.debug('New background: %s,%s,%s' % (background, colour, pixmap))
         if background == gnomeapplet.NO_BACKGROUND:
-            #widget.modify_style(gtk.RcStyle())
             pass
         elif background == gnomeapplet.COLOR_BACKGROUND:
-            widget.modify_bg(gtk.STATE_NORMAL, colour)
+            self.applet.modify_bg(gtk.STATE_NORMAL, colour)
         elif background == gnomeapplet.PIXMAP_BACKGROUND:
-            pass
+            copy = self.applet.get_style().copy()
+            copy.bg_pixmap[gtk.STATE_NORMAL] = pixmap
+            self.applet.set_style(copy)
 
     def on_dragdata_received(self, widget, context, x, y, selection, ttype,
                              time):
